Re-exports
pub use read_model_store::PostgresReadModelStore;
Modules
- read_
model_ store - Postgres Read Model Store
Structs
- Postgres
Event Store - Postgres implementation of
EventStore.
Traits
- Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- Serialize
- A data structure that can be serialized into any data format supported by Serde.